@@ -1,9 +1,6 @@
 import os
 import asyncio
 from metaapi_cloud_sdk import MetaApi
-dotenv_path = os.path.join(os.path.dirname(__file__), '.env')
-if os.path.exists(dotenv_path):
-    load_dotenv(dotenv_path)
 
 token = os.getenv('TOKEN') or '<put in your token here>'
 login = os.getenv('LOGIN') or '<put in your MT login here>'
@@ -11,6 +8,7 @@ password = os.getenv('PASSWORD') or '<put in your MT password here>'
 server_name = os.getenv('SERVER') or '<put in your MT server name here>'
 broker_srv_file = os.getenv('PATH_TO_BROKER_SRV') or '/path/to/your/broker.srv'
 api = MetaApi(token)
+# Note: for information on how to use this example code please read https://metaapi.cloud/docs/client/usingCodeExamples
 
 
 async def test_meta_api_synchronization():
@@ -87,7 +85,7 @@ async def test_meta_api_synchronization():
 
         # trade
         print('Submitting pending order')
-        result = await connection.create_limit_buy_order('GBPUSD', 0.07, 1.0, 0.9, 2.0, 'comment',
+        result = await connection.create_limit_buy_order('GBPUSD', 0.07, 1.0, 0.9, 2.0, 'comm',
                                                          'TE_GBPUSD_7hyINWqAlE')
         if result['description'] == 'TRADE_RETCODE_DONE':
             print('Trade successful')
